@@ -100,7 +100,7 @@ def _handle_file_changes(data_loader):
 
 def _get_conf_files(local_file_list):
     cur_dir = op.dirname(
-        op.dirname(op.dirname(op.dirname(op.dirname(op.abspath(__file__)))))
+        op.dirname(op.dirname(op.dirname(op.abspath(__file__))))
     )
     files = []
     for f in local_file_list:
